/************************************************************
 * HMMER - Biological sequence analysis with profile HMMs
 * Copyright (C) 1992-1999 Washington University School of Medicine
 * All Rights Reserved
 * 
 *     This source code is distributed under the terms of the
 *     GNU General Public License. See the files COPYING and LICENSE
 *     for details.
 ************************************************************/

/* marwis_func.h 
 *
 * Declarations of external functions in HMMER by M. Wistrand.
 */            

#ifndef MFUNCSH_INCLUDED
#define MFUNCSH_INCLUDED

#include "config.h"
#include "structs.h"
#include "marwis_structs.h"
#include "squid.h"
#include "msa.h"


/* marwis_func.c
 * External functions written by Markus Wistrand
 */

extern void RelativeEntropy(struct plan7_s *hmm, float *relative_entropy);    /* April 03 */
extern void P7TraceCountNegatives(float **t,  struct plan7_s *hmm, char *dsq, float wt, struct p7trace_s *tr); /* May 03 */


/* alphabet.c-like */
extern void  SequencesAlignment(MSA *msa, char ***ret_seq, int **ret_sqlen);  /*marwis March 03 */


/* should be in hmmbuild.c, just like maximum_entropy is */
extern void adjust_transitions_grad(struct plan7_s *hmm, char **dsq,  MSA *msa,
			       struct p7trace_s **tr, int nsample,
			       int nnoise,  int noseq, int maxnoseq, int max_iter);

extern void adjust_transitions_trueneg(struct plan7_s *hmm, char **dsq,  MSA *msa,
				       struct p7trace_s **tr, char **nrseqs, SQINFO *nsqinfo, int nnum,
			       int nnoise,  int noseq, int maxnoseq, int max_iter);

extern void adjust_transitions_post(struct plan7_s *hmm, char **dsq,  MSA *msa,
			       struct p7trace_s **tr, int nsample,
			       int nnoise,  int noseq, int maxnoseq);

extern void position_densities(struct plan7_s *hmm, char **seq, float *wgt,
				   int nseq, struct p7trace_s **tr, struct state_densities *dens);

/* postprob.c-like */
/* marwis, also defined in funcs.h, I don't know why... */
extern void P7TransitionExpected(int L, float w, struct plan7_s *hmm, struct dpmatrix_s *forward, struct dpmatrix_s *backward, int **ret_trs);
/*extern void P7TransitionExpected(int L, 
				 struct plan7_s *hmm,
				 struct dpmatrix_s *forward,
				 struct dpmatrix_s *backward,
				 int **ret_trs);
*/

extern void FreeSeqscore_s(struct seqscore_s *rnd, int dim1);
extern void FreeState_densities(struct state_densities *dens);

extern void SampleAndScore(struct plan7_s *hmm, struct seqscore_s **ret_rnd, int nsample, int nnoise, 
	       int seed, int fixedlen, float lenmean, float lensd);
extern void NegativesScore(struct plan7_s *hmm, struct seqscore_s **ret_rnd, int nnoise,
			   int nnum, char **nrseq,  SQINFO *nsqinfo); 
extern void PushList(struct seqscore_s *rnd, float score, int sqlen, char *seq, char *dsqtmp, int ndnoise);
extern void AddToList(struct seqscore_s *rnd, float score, int sqlen, char *seq, char *dsqtmp, int added); 
extern void IndexSortList(int *ret_list, float *score, int lth);


#endif /*MFUNCSH_INCLUDED*/
